Range-v3: ranges::v3::view::iter_transform_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Public Types | Public Member Functions | List of all members
ranges::v3::view::iter_transform_fn Struct Reference

## Synopsis of methods
constexpr view< iter_transform_fn > | iter_transform {}

## Public Types
template<typename Rng , typename Fun >
using | Concept = meta::and_< InputRange< Rng >, CopyConstructible< Fun >, Invocable< Fun &, iterator_t< Rng > >, Invocable< Fun &, copy_tag, iterator_t< Rng > >, Invocable< Fun &, move_tag, iterator_t< Rng > >>
template<typename Rng1 , typename Rng2 , typename Fun >
using | Concept2 = meta::and_< InputRange< Rng1 >, InputRange< Rng2 >, CopyConstructible< Fun >, Invocable< Fun &, iterator_t< Rng1 >, iterator_t< Rng2 > >, Invocable< Fun &, copy_tag, iterator_t< Rng1 >, iterator_t< Rng2 > >, Invocable< Fun &, move_tag, iterator_t< Rng1 >, iterator_t< Rng2 > >>

## Public Member Functions
template<typename Rng , typename Fun , requires = (Concept<Rng, Fun>())>
iter_transform_view< all_t< Rng >, Fun > | operator() (Rng &&rng, Fun fun) const
template<typename Rng1 , typename Rng2 , typename Fun , requires = (Concept2<Rng1, Rng2, Fun>())>
iter_transform2_view< all_t< Rng1 >, all_t< Rng2 >, Fun > | operator() (Rng1 &&rng1, Rng2 &&rng2, Fun fun) const